@@ -265,6 +265,36 @@ def compile_macros(macros):
     """
     import quickstats
     quickstats.compile_macros(macros)
+    
+@click.command(name='add_macro')
+@click.option('-i', '--input_path', 'path', required=True,
+              help='Path to the directory containing the source file for the macro.')
+@click.option('-n', '--name',
+              help='Name of the macro. By default, the name of the input directory is used.')
+@click.option('--copy-files/--do-not-copy-files', 'copy_files', default=True,
+              help='Whether to copy files from the input directory (required if not already copied).')
+@click.option('--add-to-workspace-extension/--do-not-add-to-workspace-extension', 'workspace_extension',
+              default=True, show_default=True,
+              help='Whether to include the macro as part of the workspace extensions.')
+def add_macro(**kwargs):
+    """
+    Add a ROOT macro to the module
+    """
+    import quickstats
+    quickstats.add_macro(**kwargs)
+    
+@click.command(name='remove_macro')
+@click.option('-n', '--name', required=True,
+              help='Name of the macro.')
+@click.option('--remove-files/--do-not-remove-files', 'remove_files',
+              default=False, show_default=True,
+              help='Whether to remove the macro from the workspace extension list only or also remove the files.')
+def remove_macro(**kwargs):
+    """
+    Remove a ROOT macro from the module
+    """    
+    import quickstats
+    quickstats.remove_macro(**kwargs)
 
 @click.command(name='harmonize_np')
 @click.argument('ws_files', nargs=-1)
