@@ -31,6 +31,8 @@ import click
               help='Name of output')
 @click.option('--outdir', default='likelihood_scan', show_default=True,
               help='Output directory.')
+@click.option('--cachedir', default='cache', show_default=True,
+              help='Cache directory relative to the output directory.')
 @click.option('--save_log/--skip_log', default=True, show_default=True,
               help='Save log file.')
 @click.option('-w', '--workspace', 'ws_name', default=None, show_default=True,
@@ -90,7 +92,7 @@ def likelihood_scan(**kwargs):
     """
     _kwargs = {}
     for arg_name in ["input_file", "param_expr", "data_name", "outdir", "filter_expr", "uncond_snapshot",
-                     "exclude_expr", "outname", "cache", "save_log", "parallel", "verbosity"]:
+                     "exclude_expr", "outname", "cache", "cachedir", "save_log", "parallel", "verbosity"]:
         _kwargs[arg_name] = kwargs.pop(arg_name)
     _kwargs['config'] = kwargs
     
