@@ -23,6 +23,8 @@ import click
                    '\b Refer to documentation for more information\n')
 @click.option('--outdir', default='output', show_default=True,
               help='Output directory where cached limit files and merged limit file are saved.')
+@click.option('--cachedir', default='cache', show_default=True,
+              help='Cache directory relative to the output directory.')
 @click.option('-o', '--outname', default='limits.json', show_default=True,
               help='Name of output limit file (all parameter points merged).')
 @click.option('--cache/--no-cache', default=True, show_default=True,
@@ -119,7 +121,7 @@ def limit_scan(**kwargs):
     _kwargs = {}
     for arg_name in ["input_path", "file_expr", "param_expr", "outdir", 
                      "filter_expr", "exclude_expr", "outname", "cache",
-                     "save_log", "save_summary", "parallel"]:
+                     "cachedir", "save_log", "save_summary", "parallel"]:
         _kwargs[arg_name] = kwargs.pop(arg_name)
     _kwargs['config'] = kwargs
     from quickstats.concurrent import ParameterisedAsymptoticCLs
