@@ -23,12 +23,16 @@ class AnalysisObject(AbstractObject):
                  fix_cache:bool=True, fix_multi:bool=True, max_calls:int=-1, 
                  max_iters:int=-1, constrain_nuis:bool=True, batch_mode:bool=False,
                  int_bin_precision:float=-1., preset_param:bool=False,
+                 minimizer_cls=None,
                  verbosity:Optional[Union[int, str]]="INFO"):
         super().__init__(verbosity=verbosity)    
         self.model = None
         self.minimizer = None
         self._use_blind_range = False
-        
+        if minimizer_cls is None:
+            self.minimizer_cls = ExtendedMinimizer
+        else:
+            self.minimizer_cls = minimizer_cls
         if filename is not None:
             self.setup_model(filename, data_name, binned_likelihood, ws_name, mc_name, 
                              snapshot_name, fix_cache, fix_multi, verbosity=verbosity)
@@ -170,7 +174,7 @@ class AnalysisObject(AbstractObject):
                         timer:bool=False, constrain_nuis:bool=True, batch_mode:bool=False,
                         int_bin_precision:float=-1., verbosity:Optional[Union[int, str]]="INFO"):
         
-        minimizer = ExtendedMinimizer("Minimizer", self.model.pdf, self.model.data, verbosity=verbosity)
+        minimizer = self.minimizer_cls("Minimizer", self.model.pdf, self.model.data, verbosity=verbosity)
         
         nll_options = {
             "num_cpu": num_cpu,
