@@ -367,7 +367,12 @@ class ExtendedModel(AbstractObject):
             else:
                 selected_params = [sname for sname in source_names if fnmatch.fnmatch(sname, name)]
             if not selected_params:
-                self.stdout.warning(f'WARNING: Parameter "{name}" does not exist. No modification will be made.', "red")
+                # check the possibility that the parameter is not a variable
+                param = self.workspace.obj(name)
+                if param:
+                    selected_params = [param]
+                else:
+                    self.stdout.warning(f'WARNING: Parameter "{name}" does not exist. No modification will be made.', "red")
             for param in selected_params:
                 if isinstance(param, str):
                     param = source[param]
@@ -379,6 +384,14 @@ class ExtendedModel(AbstractObject):
                        mode:Union[str, SetValueMode]=SetValueMode.UNCHANGED):
         mode = SetValueMode.parse(mode)
         name = param.GetName()
+        if not isinstance(param, ROOT.RooRealVar):
+            if mode == SetValueMode.FIX:
+                param.setConstant(1)
+                self.stdout.info(f"INFO: Fixed object \"{name}\" as constant.")
+            elif mode == SetValueMode.FREE:
+                param.setConstant(0)
+                self.stdout.info(f"INFO: Float object \"{name}\".")
+            return None
         old_value = param.getVal()
         new_value = old_value
         if isinstance(value, (float, int)):
