@@ -6,7 +6,7 @@ import fnmatch
 
 import ROOT
 
-from quickstats.components import AbstractObject
+from quickstats import AbstractObject
 from quickstats.utils.common_utils import str_list_filter
 
 class RooInspector(AbstractObject):
