@@ -38,9 +38,11 @@ class BracketType(GeneralEnum):
     CURLY  = (3, r"(.+){(.+)}")
     ANGLE  = (4, r"(.+)<(.+)>")
     
-    def __init__(self, enum_id:int, regex):
-        self.enum_id = enum_id
-        self.regex = re.compile(regex)
+    def __new__(cls, value:int, regex:str):
+        obj = object.__new__(cls)
+        obj._value_ = value
+        obj.regex = re.compile(regex)
+        return obj
     
 ConversionOperators = {
     XMLAttribType.STR: str,
