@@ -149,21 +149,21 @@ class XMLWSBuilder(XMLWSBase):
         # parse basic attributes
         attributes = core_xml['attrib']
         content = {
-            'base_dir': os.path.dirname(filename),
-            'workspace_name': attributes['WorkspaceName'],
-            'model_config_name': attributes['ModelConfigName'],
-            'dataset_name': attributes['DataName'],
-            'output_name': attributes['OutputFile'],
-            'do_blind': int(attributes.get('Blind', "0")),
-            'integrator': attributes.get('Integrator', ""),
-            'poi_names': [],
-            'input_categories': [],
-            'asimov_definitions': []
+            'base_dir'           : os.path.dirname(filename),
+            'workspace_name'     : attributes['WorkspaceName'],
+            'model_config_name'  : attributes['ModelConfigName'],
+            'dataset_name'       : attributes['DataName'],
+            'output_name'        : attributes['OutputFile'],
+            'do_blind'           : int(attributes.get('Blind', "0")),
+            'integrator'         : attributes.get('Integrator', ""),
+            'poi_names'          : [],
+            'input_categories'   : [],
+            'asimov_definitions' : []
         }
         if not content['output_name'].endswith(".root"):
             content['output_name'] = os.path.splitext(content['output_name'])[0] + ".root"
-            self.stdout.info("WARNING: Output file name does not contain \".root\" postfix. "
-                             "Adding it to avoid confusion.")
+            self.stdout.warning('WARNING: Output file name does not contain ".root" postfix. '
+                                'Adding it to avoid confusion.')
         # parse child level attributes
         nodes = core_xml['children']
         for node in nodes:
@@ -189,7 +189,7 @@ class XMLWSBuilder(XMLWSBase):
         self.stdout.info("Workspace name: ".rjust(20) + f"{self.core_config['workspace_name']}")
         self.stdout.info("ModelConfig name: ".rjust(20) + f"{self.core_config['model_config_name']}")
         self.stdout.info("Dataset name: ".rjust(20) + f"{self.core_config['dataset_name']}")
-        self.stdout.info("Bline analysis: ".rjust(20) + ("True" if self.core_config['do_blind'] else "False"))
+        self.stdout.info("Blind analysis: ".rjust(20) + ("True" if self.core_config['do_blind'] else "False"))
         self.stdout.info("POIs: ".rjust(20) + ", ".join(self.core_config['poi_names']))
         self.stdout.info("")
         self.stdout.info("Categories to be included:")
@@ -404,7 +404,7 @@ class XMLWSBuilder(XMLWSBase):
         nodes = cat_xml['children']
         category_name = attributes['Name']
         if category_name in self.cat_config:
-            raise RuntimeError(f"duplicated category name: `{category_name}`")
+            raise RuntimeError(f'duplicated category name: "{category_name}"')
             
         title_str = format_delimiter_enclosed_text(f"Category {category_name}", "-")
         self.stdout.info(title_str)
