@@ -8,6 +8,9 @@ import fnmatch
 from .enums import GeneralEnum
 from .abstract_object import AbstractObject
 
+from dataclasses import MISSING, _MISSING_TYPE
+
+
 class BasicConfigTypes(GeneralEnum):
     NONE        = (0, lambda x: x is None)
     ANY         = (1, lambda x: True)
@@ -18,9 +21,11 @@ class BasicConfigTypes(GeneralEnum):
     LIST        = (6, lambda x: isinstance(x, list))
     DICT        = (7, lambda x: isinstance(x, dict))
     
-    def __init__(self, value:int, validate_method:Callable):
-        self._value_ = value
-        self.validate = validate_method
+    def __new__(cls, value:int, validate_method:Callable):
+        obj = object.__new__(cls)
+        obj._value_ = value
+        obj.validate = validate_method
+        return obj
 
 class CompositeConfigTypes(object):
     
@@ -109,11 +114,23 @@ class ConfigComponent(object):
     
     @default.setter
     def default(self, value):
-        if value is None:
-            self._default = None
+        if value == MISSING:
+            self._default = MISSING
         else:
             self.type_check(value)
             self._default = value
+            
+    @property
+    def default_factory(self):
+        return self._default_factory
+    
+    @default_factory.setter
+    def default_factory(self, value):
+        if value == MISSING:
+            self._default_factory = MISSING
+        else:
+            self.type_check(value())
+            self._default_factory = value            
     
     @property
     def description(self):
@@ -168,7 +185,8 @@ class ConfigComponent(object):
     def __init__(self, dtypes:Union[str, Tuple[str], List[str]]="ANY",
                  name:str="",
                  required:bool=False,
-                 default:Optional[Any]=None,
+                 default:Optional[Any]=MISSING,
+                 default_factory:Optional[Callable]=MISSING,
                  description:Optional[str]=None,
                  example:Optional[str]=None,
                  choice:Optional[List[Any]]=None,
@@ -180,6 +198,10 @@ class ConfigComponent(object):
         self.required_strict = False
         self.choice = choice
         self.default = default
+        self.default_factory = default_factory
+        if ((not isinstance(self.default, _MISSING_TYPE)) and
+            (not isinstance(self.default_factory, _MISSING_TYPE))):
+            raise ValueError('cannot specify both default and default_factory')
         self.description = description
         self.example = example
         self.deprecated = deprecated
@@ -190,16 +212,25 @@ class ConfigComponent(object):
         if not passed:
             raise RuntimeError(f'Type check failed for the config component "{self.name}". '
                                f'Allowed types: {", ".join([dtype.name for dtype in self.dtypes])}')
+            
+    def has_default(self):
+        return ((not isinstance(self.default, _MISSING_TYPE)) or 
+                (not isinstance(self.default_factory, _MISSING_TYPE)))
+    
+    def get_default(self):
+        if not isinstance(self.default, _MISSING_TYPE):
+            return self.default
+        if not isinstance(self.default_factory, _MISSING_TYPE):
+            return self.default_factory()
+        raise RuntimeError('default value not set')
 
-    def validate(self, value=None):
-        if (value is None):
-            if self.required or (self.required_strict and (self.default is None)):
+    def validate(self, value=MISSING):
+        if isinstance(value, _MISSING_TYPE):
+            # throw error if missing value but no default value available
+            if self.required or (self.required_strict and (not self.has_default())):
                 raise RuntimeError(f'Missing value for the config component "{self.name}":\n'
                                    f'{self.get_explain_text()}')
-            if isinstance(self.default, (list, dict)):
-                return copy.deepcopy(self.default)
-            else:
-                return self.default
+            return self.get_default()
         self.type_check(value)
         if (self.choice is not None) and (value not in self.choice):
             raise RuntimeError(f'Invalid value for the config component "{self.name}". '
@@ -211,13 +242,15 @@ class ConfigComponent(object):
             "dtype"       : "|".join([dtype.name for dtype in self.dtypes]),
             "required"    : str(self.required),
         }
-        if self.default is not None:
-            components["default"] = str(self.default)
+        if self.has_default():
+            components["default"] = str(self.get_default())
         components["description"] = self.description
         if self.example is not None:
             components["example"] = self.example
         if self.deprecated:
             components["deprecation"] = self.deprecation_message
+        if self.choice is not None:
+            components["choice"] = ", ".join([f"{i}" for i in self.choice])
             
         from quickstats.utils.common_utils import itemize_dict
         text = itemize_dict(components, leftmargin=leftmargin, linebreak=linebreak)
@@ -247,21 +280,31 @@ class ConfigParser(AbstractObject):
         
     def __init__(self, config_format:Dict,
                  required_components:Optional[List[str]]=None,
+                 optional_components:Optional[List[str]]=None,
                  disable_message:bool=False,
                  verbosity:Optional[Union[int, str]]="INFO"):
         self.config_format = config_format
-        self.set_required_components(required_components)
+        self.set_components_requirement(required_components, optional_components)
         self.disable_message = disable_message
         
-    def set_required_components(self, required_components:Optional[List[str]]=None):
+    def set_components_requirement(self, required_components:Optional[List[str]]=None,
+                                   optional_components:Optional[List[str]]=None):
+        
+        # require everything by default
         if required_components is None:
-            required_components = []
+            required_components = ["*"]
+        if optional_components is None:
+            optional_components = []            
         for label, component in self.component_map.items():
             component.required_strict = False
             for required_component in required_components:
                 if fnmatch.fnmatch(label, required_component):
                     component.required_strict = True
                     break
+            for optional_component in optional_components:
+                if fnmatch.fnmatch(label, required_component):
+                    component.required_strict = False
+                    break
                     
     def get_required_components(self):
         components = [component for component in self.component_map.values() if component.required_strict]
@@ -368,7 +411,7 @@ class ConfigParser(AbstractObject):
         if isinstance(config, str):
             extension = os.path.splitext(config)[-1]
             if not self.disable_message:
-                self.stdout.info(f'INFO: Reading config file "{config}".')
+                self.stdout.info(f'INFO: Reading configuration file "{config}".')
             if extension == ".json":
                 import json
                 with open(config, "r") as file:
@@ -424,7 +467,7 @@ class ConfigParser(AbstractObject):
                 else:
                     # only fill default if component is strictly required
                     if component.required_strict:
-                        config[key] = component.validate(None)
+                        config[key] = component.validate(MISSING)
                         if not self.disable_message:
                             self.stdout.info(f'INFO: Auto-filled missing config component "{config_label}" with '
                                          f'default value "{config[key]}".')
