@@ -6,7 +6,7 @@ from quickstats import semistaticmethod
 
 class RooAbsData:
     @staticmethod
-    def create_histogram(data, *args):
+    def create_histogram(data:"ROOT.RooAbsData", *args):
         h = data.createHistogram(*args)
         import ROOT
         if isinstance(h, ROOT.TH1):
