@@ -151,4 +151,9 @@ def get_proper_ranges(ranges:Union[List[float], List[List[float]]],
     if no_overlap:
         if not np.all(np.diff(ranges.flatten()) >= 0):
             raise ValueError("found overlap ranges")
-    return ranges
\ No newline at end of file
+    return ranges
+
+def get_batch_slice_indices(totalsize:int, batchsize:int):
+    assert (totalsize > 0) and (batchsize > 0)
+    for i in range(0, totalsize, batchsize):
+        yield (i, min(i + batchsize, totalsize))
\ No newline at end of file
