@@ -87,7 +87,9 @@ class Histo1DPlot(AbstractPlot):
         
         if n_columns > 1:
             ax.legend(**self.styles['legend'])
-        
+        # update axis offset text
+        import matplotlib.pyplot as plt
+        plt.tight_layout()
         self.draw_axis_components(ax, xlabel=xlabel, ylabel=ylabel)
         self.set_axis_range(ax, xmin=xmin, xmax=xmax, ypad=ypad)  
         
