@@ -348,8 +348,8 @@ class NPRankingPlot:
             impact_types.append('postfit')
         if show_prefit:
             impact_types.append('prefit')
-        if not correlation:
-            impact_types = impact_types[::-1]
+        #if not correlation:
+        #    impact_types = impact_types[::-1]
         for it in impact_types:
             prefix = 'impact_{}'.format(it)
             # retrieve the impact data
