@@ -455,7 +455,7 @@ class PdfDistributionPlot(AbstractPlot):
                 labelsize = options.get('labelsize', None)
                 styles    = options.get('styles', {})
                 draw_ratio_line = options.get('draw_ratio_line', True)
-                plot_options = self.plot_options.get(reference, {})
+                plot_options = self.plot_options.get(target, {})
                 if ('color' not in plot_options) and (target in self.colors):
                     plot_options['color'] = self.colors[target]
                 plot_options.update(styles)
