@@ -53,7 +53,7 @@ def release_tfiles():
         f.Close()
 
 def compile_macro(name:str, opt:str="kfOc"):
-    macros_dir = os.path.join(quickstats.macro_path, 'macros', name)
+    macros_dir = os.path.join(quickstats.macro_path, name)
     macros_path = os.path.join(macros_dir, name + '.cxx')
     print('INFO: Compiling macro "{}"...'.format(name))
     if not os.path.exists(macros_path):
@@ -74,7 +74,7 @@ def load_macro(name:str):
     class_loaded = hasattr(ROOT, name)
     if class_loaded:
         return None
-    macros_dir = os.path.join(quickstats.macro_path, 'macros', name)
+    macros_dir = os.path.join(quickstats.macro_path, name)
     macros_path = os.path.join(macros_dir, name + '_cxx')
     if not os.path.exists(macros_path + '.so'):
         status_compile = compile_macro(name)
@@ -86,7 +86,7 @@ def load_macro(name:str):
     return status_load
 
 def get_macro_dir(name:str):
-    return os.path.join(quickstats.macro_path, 'macros', name)
+    return os.path.join(quickstats.macro_path, name)
 
 def get_macro_TClass(name:str):
     if not getattr(ROOT, name):
